@@ -11,20 +11,20 @@ import lightkurve as lk
 import numpy as np
 import os
 import sys
-from objectinfo.MissionObjectInfo import MissionObjectInfo
-from objectinfo.InputObjectInfo import InputObjectInfo
-from objectinfo.MissionFfiIdObjectInfo import MissionFfiIdObjectInfo
-from objectinfo.MissionInputObjectInfo import MissionInputObjectInfo
-from objectinfo.MissionFfiCoordsObjectInfo import MissionFfiCoordsObjectInfo
-from objectinfo.preparer.MissionFfiLightcurveBuilder import MissionFfiLightcurveBuilder
-from objectinfo.preparer.MissionInputLightcurveBuilder import MissionInputLightcurveBuilder
-from objectinfo.preparer.MissionLightcurveBuilder import MissionLightcurveBuilder
-from scoring.BasicSignalSelector import BasicSignalSelector
-from scoring.SnrBorderCorrectedSignalSelector import SnrBorderCorrectedSignalSelector
-from scoring.QuorumSnrBorderCorrectedSignalSelector import QuorumSnrBorderCorrectedSignalSelector
-from ois.OisManager import OisManager
-from star.HabitabilityCalculator import HabitabilityCalculator
-from transitresult import TransitResult
+from sherlockpipe.objectinfo.MissionObjectInfo import MissionObjectInfo
+from sherlockpipe.objectinfo.InputObjectInfo import InputObjectInfo
+from sherlockpipe.objectinfo.MissionFfiIdObjectInfo import MissionFfiIdObjectInfo
+from sherlockpipe.objectinfo.MissionInputObjectInfo import MissionInputObjectInfo
+from sherlockpipe.objectinfo.MissionFfiCoordsObjectInfo import MissionFfiCoordsObjectInfo
+from sherlockpipe.objectinfo.preparer.MissionFfiLightcurveBuilder import MissionFfiLightcurveBuilder
+from sherlockpipe.objectinfo.preparer.MissionInputLightcurveBuilder import MissionInputLightcurveBuilder
+from sherlockpipe.objectinfo.preparer.MissionLightcurveBuilder import MissionLightcurveBuilder
+from sherlockpipe.scoring.BasicSignalSelector import BasicSignalSelector
+from sherlockpipe.scoring.SnrBorderCorrectedSignalSelector import SnrBorderCorrectedSignalSelector
+from sherlockpipe.scoring.QuorumSnrBorderCorrectedSignalSelector import QuorumSnrBorderCorrectedSignalSelector
+from sherlockpipe.ois.OisManager import OisManager
+from sherlockpipe.star.HabitabilityCalculator import HabitabilityCalculator
+from sherlockpipe.transitresult import TransitResult
 from multiprocessing import Pool
 from scipy.signal import argrelextrema, savgol_filter
 from scipy.ndimage.interpolation import shift
